@@ -2,6 +2,12 @@ import mpmath
 from mpmath import *
 from mpmath.libmp import *
 import random
+import sys
+
+try:
+    long = long
+except NameError:
+    long = int
 
 def test_type_compare():
     assert mpf(2) == mpc(2,0)
@@ -119,10 +125,10 @@ def test_complex_misc():
 
 def test_complex_zeros():
     for a in [0,2]:
-      for b in [0,3]:
-        for c in [0,4]:
-          for d in [0,5]:
-            assert mpc(a,b)*mpc(c,d) == complex(a,b)*complex(c,d)
+        for b in [0,3]:
+            for c in [0,4]:
+                for d in [0,5]:
+                    assert mpc(a,b)*mpc(c,d) == complex(a,b)*complex(c,d)
 
 def test_hash():
     for i in range(-256, 256):
@@ -141,6 +147,9 @@ def test_hash():
     assert hash(mp.mpq(1,1)) == hash(1)
     assert hash(mp.mpq(5,1)) == hash(5)
     assert hash(mp.mpq(1,2)) == hash(0.5)
+    if sys.version >= "3.2":
+        assert hash(mpf(1)*2**2000) == hash(2**2000)
+        assert hash(mpf(1)/2**2000) == hash(mpq(1,2**2000))
 
 # Advanced rounding test
 def test_add_rounding():
@@ -159,7 +168,7 @@ def test_almost_equal():
 def test_arithmetic_functions():
     import operator
     ops = [(operator.add, fadd), (operator.sub, fsub), (operator.mul, fmul),
-        (operator.div, fdiv)]
+        (operator.truediv, fdiv)]
     a = mpf(0.27)
     b = mpf(1.13)
     c = mpc(0.51+2.16j)
@@ -188,23 +197,23 @@ def test_exact_integer_arithmetic():
     # XXX: re-fix this so that all operations are tested with all rounding modes
     random.seed(0)
     for prec in [6, 10, 25, 40, 100, 250, 725]:
-      for rounding in ['d', 'u', 'f', 'c', 'n']:
-        mp.dps = prec
-        M = 10**(prec-2)
-        M2 = 10**(prec//2-2)
-        for i in range(10):
-            a = random.randint(-M, M)
-            b = random.randint(-M, M)
-            assert mpf(a, rounding=rounding) == a
-            assert int(mpf(a, rounding=rounding)) == a
-            assert int(mpf(str(a), rounding=rounding)) == a
-            assert mpf(a) + mpf(b) == a + b
-            assert mpf(a) - mpf(b) == a - b
-            assert -mpf(a) == -a
-            a = random.randint(-M2, M2)
-            b = random.randint(-M2, M2)
-            assert mpf(a) * mpf(b) == a*b
-            assert mpf_mul(from_int(a), from_int(b), mp.prec, rounding) == from_int(a*b)
+        for rounding in ['d', 'u', 'f', 'c', 'n']:
+            mp.dps = prec
+            M = 10**(prec-2)
+            M2 = 10**(prec//2-2)
+            for i in range(10):
+                a = random.randint(-M, M)
+                b = random.randint(-M, M)
+                assert mpf(a, rounding=rounding) == a
+                assert int(mpf(a, rounding=rounding)) == a
+                assert int(mpf(str(a), rounding=rounding)) == a
+                assert mpf(a) + mpf(b) == a + b
+                assert mpf(a) - mpf(b) == a - b
+                assert -mpf(a) == -a
+                a = random.randint(-M2, M2)
+                b = random.randint(-M2, M2)
+                assert mpf(a) * mpf(b) == a*b
+                assert mpf_mul(from_int(a), from_int(b), mp.prec, rounding) == from_int(a*b)
     mp.dps = 15
 
 def test_odd_int_bug():
@@ -390,8 +399,8 @@ def test_isnan_etc():
     assert isnormal(mpq((0,1))) == False
     assert isint(3) == True
     assert isint(0) == True
-    assert isint(3L) == True
-    assert isint(0L) == True
+    assert isint(long(3)) == True
+    assert isint(long(0)) == True
     assert isint(mpf(3)) == True
     assert isint(mpf(0)) == True
     assert isint(mpf(-3)) == True
